Structs
- Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
- License
Assignment - Representation of a license assignment.
- License
Assignment Delete Call - Revoke a license.
- License
Assignment GetCall - Get a specific user’s license by product SKU.
- License
Assignment Insert - Representation of a license assignment.
- License
Assignment Insert Call - Assign a license.
- License
Assignment List - There is no detailed description.
- License
Assignment List ForProduct AndSku Call - List all users assigned licenses for a specific product SKU.
- License
Assignment List ForProduct Call - List all users assigned licenses for a specific product SKU.
- License
Assignment Methods - A builder providing access to all methods supported on licenseAssignment resources.
It is not used directly, but through the
Licensinghub. - License
Assignment Patch Call - Reassign a user’s product SKU with a different SKU in the same product. This method supports patch semantics.
- License
Assignment Update Call - Reassign a user’s product SKU with a different SKU in the same product.
- Licensing
- Central instance to access all Licensing related resource activities
Enums
- Scope
- Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.